Stan Math Library: stan/math/prim/scal/fun/identity_free.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
identity_free.hpp File Reference

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
T | stan::math::identity_free (const T y)
| Returns the result of applying the inverse of the identity constraint transform to the input. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.